#[validate_deser]Expand description
Attribute serde-validate-macro to derive deserialization with validation for a struct or enum.
This serde-validate-macro generates a helper struct to deserialize the original struct or enum and
then validates the deserialized data using the serde_validate::Validate trait. If validation fails,
a deserialization error is returned.